import { AttendeeInfo } from "../Misc/Availability/AttendeeInfo";
import { TimeWindow } from "../Misc/Availability/TimeWindow";
import { AvailabilityData } from "../Enumerations/AvailabilityData";
import { AvailabilityOptions } from "../Misc/Availability/AvailabilityOptions";
import { GetUserAvailabilityResults } from "../Misc/Availability/GetUserAvailabilityResults";
import { GroupedFindItemsResults } from "../Search/GroupedFindItemsResults";
import { FindItemsResults } from "../Search/FindItemsResults";
import { Item } from "./ServiceObjects/Items/Item";
import { ViewBase } from "../Search/ViewBase";
import { Grouping } from "../Search/Grouping";
import { FindItemResponse } from "./Responses/FindItemResponse";
import { ManagementRoles } from "../Misc/ManagementRoles";
import { ImpersonatedUserId } from "../Misc/ImpersonatedUserId";
import { PrivilegedUserId } from "../Misc/PrivilegedUserId";
import { IFileAttachmentContentHandler } from "../Interfaces/IFileAttachmentContentHandler";
import { UnifiedMessaging } from "../UnifiedMessaging/UnifiedMessaging";
import { DeleteMode } from "../Enumerations/DeleteMode";
import { ServiceResponse } from "./Responses/ServiceResponse";
import { ServiceObject } from "./ServiceObjects/ServiceObject";
import { AutodiscoverRedirectionUrlValidationCallback } from "../Autodiscover/AutodiscoverServiceDelegates";
import { RenderingMode } from "../Enumerations/RenderingMode";
import { MessageDisposition } from "../Enumerations/MessageDisposition";
import { ServiceResponseCollection } from "./Responses/ServiceResponseCollection";
import { ServiceErrorHandling } from "../Enumerations/ServiceErrorHandling";
import { DateTimePrecision } from "../Enumerations/DateTimePrecision";
import { WellKnownFolderName } from "../Enumerations/WellKnownFolderName";
import { SearchFilter } from "../Search/Filters/SearchFilter";
import { FindFoldersResults } from "../Search/FindFoldersResults";
import { FolderView } from "../Search/FolderView";
import { Uri } from "../Uri";
import { Folder } from "./ServiceObjects/Folders/Folder";
import { FolderId } from "../ComplexProperties/FolderId";
import { PropertySet } from "./PropertySet";
import { IPromise, IXHROptions } from "../Interfaces";
import { ExchangeServiceBase } from "./ExchangeServiceBase";
export declare class ExchangeService extends ExchangeServiceBase {
    private static TargetServerVersionHeaderName;
    private url;
    private unifiedMessaging;
    private renderingMode;
    private targetServerVersion;
    Url: Uri;
    ImpersonatedUserId: ImpersonatedUserId;
    PrivilegedUserId: PrivilegedUserId;
    ManagementRoles: ManagementRoles;
    PreferredCulture: any;
    DateTimePrecision: DateTimePrecision;
    FileAttachmentContentHandler: IFileAttachmentContentHandler;
    TimeZone: any;
    UnifiedMessaging: UnifiedMessaging;
    EnableScpLookup: boolean;
    Exchange2007CompatibilityMode: boolean;
    RenderingMethod: RenderingMode;
    TraceEnablePrettyPrinting: boolean;
    TargetServerVersion: string;
    InternalCreateResponseObject(responseObject: ServiceObject, parentFolderId: FolderId, messageDisposition: MessageDisposition): IPromise<Item[]>;
    CreateFolder(folder: Folder, parentFolderId: FolderId): IPromise<void>;
    BindToFolderAs<TFolder extends Folder>(folderId: FolderId, propertySet: PropertySet): IPromise<TFolder>;
    BindToFolder(folderId: FolderId, propertySet: PropertySet): IPromise<Folder>;
    CopyFolder(folderId: FolderId, destinationFolderId: FolderId): IPromise<Folder>;
    DeleteFolder(folderId: FolderId, deleteMode: DeleteMode): IPromise<void>;
    EmptyFolder(folderId: FolderId, deleteMode: DeleteMode, deleteSubFolders: boolean): IPromise<void>;
    FindFolders(parentFolderId: FolderId, view: FolderView): IPromise<FindFoldersResults>;
    FindFolders(parentFolderName: WellKnownFolderName, view: FolderView): IPromise<FindFoldersResults>;
    FindFolders(parentFolderId: FolderId, searchFilter: SearchFilter, view: FolderView): IPromise<FindFoldersResults>;
    FindFolders(parentFolderName: WellKnownFolderName, searchFilter: SearchFilter, view: FolderView): IPromise<FindFoldersResults>;
    private InternalFindFolders(parentFolderIds, searchFilter, view, errorHandlingMode);
    LoadPropertiesForFolder(folder: Folder, propertySet: PropertySet): IPromise<void>;
    MarkAllItemsAsRead(folderId: FolderId, readFlag: boolean, suppressReadReceipts: boolean): IPromise<void>;
    MoveFolder(folderId: FolderId, destinationFolderId: FolderId): IPromise<Folder>;
    UpdateFolder(folder: Folder): IPromise<void>;
    FindItems(parentFolderName: WellKnownFolderName, view: ViewBase): IPromise<FindItemsResults<Item>>;
    FindItems(parentFolderId: FolderId, view: ViewBase): IPromise<FindItemsResults<Item>>;
    FindItems(parentFolderId: FolderId, view: ViewBase, groupBy: Grouping): IPromise<GroupedFindItemsResults<Item>>;
    FindItems(parentFolderId: FolderId, queryString: string, view: ViewBase): IPromise<FindItemsResults<Item>>;
    FindItems(parentFolderName: WellKnownFolderName, queryString: string, view: ViewBase): IPromise<FindItemsResults<Item>>;
    FindItems(parentFolderName: WellKnownFolderName, searchFilter: SearchFilter, view: ViewBase): IPromise<FindItemsResults<Item>>;
    FindItems(parentFolderId: FolderId, searchFilter: SearchFilter, view: ViewBase): IPromise<FindItemsResults<Item>>;
    FindItems(parentFolderId: FolderId, searchFilter: SearchFilter, view: ViewBase, groupBy: Grouping): IPromise<GroupedFindItemsResults<Item>>;
    FindItems(parentFolderId: FolderId, queryString: string, view: ViewBase, groupBy: Grouping): IPromise<GroupedFindItemsResults<Item>>;
    FindItems(parentFolderName: WellKnownFolderName, searchFilter: SearchFilter, view: ViewBase, groupBy: Grouping): IPromise<GroupedFindItemsResults<Item>>;
    FindItems(parentFolderName: WellKnownFolderName, queryString: string, view: ViewBase, groupBy: Grouping): IPromise<GroupedFindItemsResults<Item>>;
    FindItems(parentFolderId: FolderId, queryString: string, returnHighlightTerms: boolean, view: ViewBase): IPromise<FindItemsResults<Item>>;
    FindItems(parentFolderId: FolderId, queryString: string, returnHighlightTerms: boolean, view: ViewBase, groupBy: Grouping): IPromise<GroupedFindItemsResults<Item>>;
    FindItems<TItem extends Item>(parentFolderIds: FolderId[], searchFilter: SearchFilter, queryString: string, view: ViewBase, groupBy: Grouping, errorHandlingMode: ServiceErrorHandling): IPromise<ServiceResponseCollection<FindItemResponse<TItem>>>;
    InternalLoadPropertiesForItems(items: Item[], propertySet: PropertySet, errorHandling: ServiceErrorHandling): ServiceResponseCollection<ServiceResponse>;
    GetUserAvailability(attendees: AttendeeInfo[], timeWindow: TimeWindow, requestedData: AvailabilityData): IPromise<GetUserAvailabilityResults>;
    GetUserAvailability(attendees: AttendeeInfo[], timeWindow: TimeWindow, requestedData: AvailabilityData, options: AvailabilityOptions): IPromise<GetUserAvailabilityResults>;
    /** #region Id conversion operations */
    private AdjustServiceUriFromCredentials(uri);
    AutodiscoverUrl(emailAddress: string): IPromise<void>;
    AutodiscoverUrl(emailAddress: string, validateRedirectionUrlCallback: AutodiscoverRedirectionUrlValidationCallback): IPromise<void>;
    private DefaultAutodiscoverRedirectionUrlValidationCallback(redirectionUrl);
    private GetAutodiscoverUrl(emailAddress, requestedServerVersion, validateRedirectionUrlCallback);
    private GetEwsUrlFromResponse(response, isExternal);
    static IsMajorMinor(versionPart: string): boolean;
    Validate(): void;
    static ValidateTargetVersion(version: string): void;
    PrepareHttpWebRequest(methodName: string): IXHROptions;
    SetContentType(request: IXHROptions): void;
}
