import { FindItemsResults } from "../../../Search/FindItemsResults";
import { PolicyTag } from "../../../ComplexProperties/PolicyTag";
import { ArchiveTag } from "../../../ComplexProperties/ArchiveTag";
import { ManagedFolderInformation } from "../../../ComplexProperties/ManagedFolderInformation";
import { FolderPermissionCollection } from "../../../ComplexProperties/FolderPermissionCollection";
import { SearchFilter } from "../../../Search/Filters/SearchFilter";
import { GroupedFindItemsResults } from "../../../Search/GroupedFindItemsResults";
import { ItemView } from "../../../Search/ItemView";
import { Item } from "../Items/Item";
import { ServiceResponseCollection } from "../../Responses/ServiceResponseCollection";
import { FindItemResponse } from "../../Responses/FindItemResponse";
import { Grouping } from "../../../Search/Grouping";
import { AffectedTaskOccurrence } from "../../../Enumerations/AffectedTaskOccurrence";
import { ViewBase } from "../../../Search/ViewBase";
import { ExtendedPropertyDefinition } from "../../../PropertyDefinitions/ExtendedPropertyDefinition";
import { PropertyDefinition } from "../../../PropertyDefinitions/PropertyDefinition";
import { ServiceObjectSchema } from "../Schemas/ServiceObjectSchema";
import { SendCancellationsMode } from "../../../Enumerations/SendCancellationsMode";
import { ExchangeVersion } from "../../../Enumerations/ExchangeVersion";
import { PropertySet } from "../../PropertySet";
import { FindFoldersResults } from "../../../Search/FindFoldersResults";
import { FolderView } from "../../../Search/FolderView";
import { DeleteMode } from "../../../Enumerations/DeleteMode";
import { ExchangeService } from "../../ExchangeService";
import { WellKnownFolderName } from "../../../Enumerations/WellKnownFolderName";
import { EffectiveRights } from "../../../Enumerations/EffectiveRights";
import { ExtendedPropertyCollection } from "../../../ComplexProperties/ExtendedPropertyCollection";
import { FolderId } from "../../../ComplexProperties/FolderId";
import { IPromise } from "../../../Interfaces";
import { ServiceObject } from "../ServiceObject";
export declare class Folder extends ServiceObject {
    Id: FolderId;
    ParentFolderId: FolderId;
    ChildFolderCount: number;
    DisplayName: string;
    FolderClass: string;
    TotalCount: number;
    ExtendedProperties: ExtendedPropertyCollection;
    ManagedFolderInformation: ManagedFolderInformation;
    EffectiveRights: EffectiveRights;
    Permissions: FolderPermissionCollection;
    UnreadCount: number;
    PolicyTag: PolicyTag;
    ArchiveTag: ArchiveTag;
    WellKnownFolderName: WellKnownFolderName;
    /**
     * _FolderTYpe -> type of folder, use to avoid folder type detection using instanceof. some cases it has circular loop in nodejs/requirejs
     */
    _FolderType: string;
    constructor(service: ExchangeService);
    static Bind(service: ExchangeService, id: FolderId): IPromise<Folder>;
    static Bind(service: ExchangeService, name: WellKnownFolderName): IPromise<Folder>;
    static Bind(service: ExchangeService, id: FolderId, propertySet: PropertySet): IPromise<Folder>;
    static Bind(service: ExchangeService, name: WellKnownFolderName, propertySet: PropertySet): IPromise<Folder>;
    Copy(destinationFolderName: WellKnownFolderName): IPromise<Folder>;
    Copy(destinationFolderId: FolderId): IPromise<Folder>;
    Delete(deleteMode: DeleteMode): IPromise<void>;
    Empty(deleteMode: DeleteMode, deleteSubFolders: boolean): IPromise<void>;
    FindFolders(view: FolderView): IPromise<FindFoldersResults>;
    FindFolders(searchFilter: SearchFilter, view: FolderView): IPromise<FindFoldersResults>;
    FindItems(view: ItemView): IPromise<FindItemsResults<Item>>;
    FindItems(view: ItemView, groupBy: Grouping): IPromise<GroupedFindItemsResults<Item>>;
    FindItems(queryString: string, view: ItemView): IPromise<FindItemsResults<Item>>;
    FindItems(searchFilter: SearchFilter, view: ItemView): IPromise<FindItemsResults<Item>>;
    FindItems(queryString: string, view: ItemView, groupBy: Grouping): IPromise<GroupedFindItemsResults<Item>>;
    FindItems(searchFilter: SearchFilter, view: ItemView, groupBy: Grouping): IPromise<GroupedFindItemsResults<Item>>;
    GetXmlElementName(): string;
    GetChangeXmlElementName(): string;
    GetDeleteFieldXmlElementName(): string;
    GetExtendedProperties(): ExtendedPropertyCollection;
    GetIdPropertyDefinition(): PropertyDefinition;
    GetMinimumRequiredServerVersion(): ExchangeVersion;
    GetSchema(): ServiceObjectSchema;
    GetSetFieldXmlElementName(): string;
    InternalDelete(deleteMode: DeleteMode, sendCancellationsMode?: SendCancellationsMode, affectedTaskOccurrences?: AffectedTaskOccurrence): IPromise<void>;
    protected InternalFindItems<TItem extends Item>(queryString: string, view: ViewBase, groupBy: Grouping): IPromise<ServiceResponseCollection<FindItemResponse<TItem>>>;
    protected InternalFindItems<TItem extends Item>(searchFilter: SearchFilter, view: ViewBase, groupBy: Grouping): IPromise<ServiceResponseCollection<FindItemResponse<TItem>>>;
    /**this is to shim find items with querystring or searchfilter. */
    protected InternalFindItems<TItem extends Item>(searchFilterOrQueryString: SearchFilter | string, view: ViewBase, groupBy: Grouping): IPromise<ServiceResponseCollection<FindItemResponse<TItem>>>;
    InternalLoad(propertySet: PropertySet): IPromise<void>;
    MarkAllItemsAsRead(suppressReadReceipts: boolean): IPromise<void>;
    MarkAllItemsAsUnread(suppressReadReceipts: boolean): IPromise<void>;
    Move(destinationFolderName: WellKnownFolderName): IPromise<Folder>;
    Move(destinationFolderId: FolderId): IPromise<Folder>;
    RemoveExtendedProperty(extendedPropertyDefinition: ExtendedPropertyDefinition): boolean;
    Save(parentFolderName: WellKnownFolderName): IPromise<void>;
    Save(parentFolderId: FolderId): IPromise<void>;
    SetExtendedProperty(extendedPropertyDefinition: ExtendedPropertyDefinition, value: any): void;
    Update(): IPromise<void>;
    Validate(): void;
    IsFolderInstance(): boolean;
}
